=======
Gnocchi
=======

Gnocchi is a service for managing a set of resources and storing metrics about
them, in a scalable and resilient way. Its functionalities are exposed over an
HTTP REST API.

There is a more consistent presentation of Gnocchi:

    https://julien.danjou.info/blog/2015/openstack-gnocchi-first-release

And online documentation:

    http://docs.openstack.org/developer/gnocchi/

Your are invited to file bug reports (if you find bugs) in
the bug tracker, available at:

   http://bugs.launchpad.net/gnocchi
